@@ -1,6 +1,6 @@
 /************************************************************************
  *
- * $Id: geos_c.cpp,v 1.16.2.3 2005/12/10 16:07:07 strk Exp $
+ * $Id: geos_c.cpp,v 1.16.2.6 2006/07/01 19:58:31 strk Exp $
  *
  * C-Wrapper for GEOS library
  *
@@ -71,6 +71,7 @@ extern "C" char GEOS_DLL GEOSOverlaps(const Geometry *g1, const Geometry *g2);
 extern "C" Geometry GEOS_DLL *GEOSpolygonize(Geometry **geoms, unsigned int ngeoms);
 extern "C" char GEOS_DLL GEOSisValid(const Geometry *g1);
 extern "C" char GEOS_DLL GEOSisEmpty(const Geometry *g1);
+extern "C" Geometry GEOS_DLL *GEOSEnvelope(Geometry *g1);
 extern "C" Geometry GEOS_DLL *GEOSIntersection(Geometry *g1,Geometry *g2);
 extern "C" Geometry GEOS_DLL *GEOSBuffer(Geometry *g1,double width,int quadsegs);
 extern "C" Geometry GEOS_DLL *GEOSConvexHull(Geometry *g1);
@@ -91,6 +92,8 @@ extern "C" Geometry GEOS_DLL *GEOSPointOnSurface(Geometry *g1);
 extern "C" Geometry GEOS_DLL *GEOSGetCentroid(Geometry *g);
 extern "C" CoordinateSequence GEOS_DLL *GEOSGeom_getCoordSeq(Geometry *g1);
 
+extern "C" int GEOS_DLL GEOSArea(const Geometry *g1, double *area);
+extern "C" int GEOS_DLL GEOSLength(const Geometry *g1, double *length);
 extern "C" int GEOS_DLL GEOSDistance(const Geometry *g1, const Geometry *g2,
 	double *dist);
 
@@ -166,6 +169,7 @@ void
 finishGEOS ()
 {
 	delete geomFactory;
+	geomFactory=0;
 }
 
 //-----------------------------------------------------------
@@ -456,12 +460,9 @@ GEOSRelate(const Geometry *g1, const Geometry *g2)
 char
 GEOSisValid(const Geometry *g1)
 {
-#if GEOS_FIRST_INTERFACE <= 3 && GEOS_LAST_INTERFACE >= 3
 	IsValidOp ivo(g1);
-#endif
 	bool result;
 	try {
-#if GEOS_FIRST_INTERFACE <= 3 && GEOS_LAST_INTERFACE >= 3
 		result = ivo.isValid();
 		if ( result == 0 )
 		{
@@ -471,9 +472,6 @@ GEOSisValid(const Geometry *g1)
 				NOTICE_MESSAGE((char *)errmsg.c_str());
 			}
 		}
-#else // GEOS_INTERFACE 3 not supported
-		result = g1->isValid();
-#endif
 		return result;
 	}
 	catch (GEOSException *ge)
@@ -530,6 +528,49 @@ GEOSEquals(const Geometry *g1, const Geometry *g2)
 	}
 }
 
+int
+GEOSArea(const Geometry *g, double *area)
+{
+	try {
+		*area = g->getArea();
+		return 1;
+	}
+
+	catch (std::exception &e)
+	{
+		ERROR_MESSAGE(e.what());
+		return 0;
+	}
+
+	catch (...)
+	{
+		ERROR_MESSAGE("Unknown exception thrown");
+		return 0;
+	}
+}
+
+int
+GEOSLength(const Geometry *g, double *length)
+{
+	try {
+		*length = g->getLength();
+		return 1;
+	}
+
+	catch (std::exception &e)
+	{
+		ERROR_MESSAGE(e.what());
+		return 0;
+	}
+
+	catch (...)
+	{
+		ERROR_MESSAGE("Unknown exception thrown");
+		return 0;
+	}
+}
+
+
 int
 GEOSDistance(const Geometry *g1, const Geometry *g2, double *dist)
 {
@@ -850,6 +891,34 @@ GEOSGeomTypeId(Geometry *g1)
 // GEOS functions that return geometries
 //-------------------------------------------------------------------
 
+Geometry *
+GEOSEnvelope(Geometry *g1)
+{
+	try
+    {
+        Geometry *g3 = g1->getEnvelope();
+        return g3;
+    }
+    catch (GEOSException *ge)
+    {
+        ERROR_MESSAGE((char *)ge->toString().c_str());
+        delete ge;
+        return NULL;
+    }
+
+    catch (std::exception &e)
+    {
+        ERROR_MESSAGE(e.what());
+        return NULL;
+    }
+
+    catch (...)
+    {
+        ERROR_MESSAGE("Unknown exception thrown");
+        return NULL;
+    }
+}
+
 Geometry *
 GEOSIntersection(Geometry *g1, Geometry *g2)
 {
@@ -1558,16 +1627,8 @@ GEOSversion()
 char *
 GEOSjtsport()
 {
-#if GEOS_LAST_INTERFACE < 2
-	/*
-	 * GEOS upgrade needs postgis re-build, so this static
-	 * assignment is not going to be a problem
-	 */
-	char *res = strdup("1.3");
-#else
 	string version = jtsport();
 	char *res = strdup(version.c_str());
-#endif
 	return res;
 }
 
@@ -1580,7 +1641,7 @@ GEOSHasZ(Geometry *g)
 	double az = g->getCoordinate()->z;
 	//sprintf(msg, "ZCoord: %g", az);
 	//ERROR_MESSAGE(msg);
-	return (finite(az) && az != DoubleNotANumber);
+	return FINITE(az);
 }
 
 int
