@@ -1,5 +1,5 @@
 /**********************************************************************
- * $Id: QuadTreeNodeBase.cpp,v 1.10 2004/11/01 16:43:04 strk Exp $
+ * $Id: QuadTreeNodeBase.cpp,v 1.10.2.1 2005/05/23 18:41:51 strk Exp $
  *
  * GEOS - Geometry Engine Open Source
  * http://geos.refractions.net
@@ -13,6 +13,7 @@
  *
  **********************************************************************/
 
+#include <sstream>
 #include <geos/indexQuadtree.h>
 
 #ifndef DEBUG
@@ -145,26 +146,25 @@ int QuadTreeNodeBase::nodeCount() {
 string
 QuadTreeNodeBase::toString() const
 {
-	char buf[10];
-	sprintf(buf, "%d", items->size());
-	string tmp = buf;
-	string ret = "ITEMS:"+tmp+"\n";
+	ostringstream s;
+	s<<"ITEMS:"<<items->size()<<endl;
 	for (int i=0; i<4; i++)
 	{
-		sprintf(buf, "%d", i);
-		tmp = buf;
-		ret += "subnode["+tmp+"]";
-		if ( subnode[i] == NULL ) ret += "NULL";
-		else ret += subnode[i]->toString();
-		ret += "\n";
+		s<<"subnode["<<i<<"] ";
+		if ( subnode[i] == NULL ) s<<"NULL";
+		else s<<subnode[i]->toString();
+		s<<endl;
 	}
-	return ret;
+	return s.str();
 }
 
 } // namespace geos
 
 /**********************************************************************
  * $Log: QuadTreeNodeBase.cpp,v $
+ * Revision 1.10.2.1  2005/05/23 18:41:51  strk
+ * Replaced sprintf uses with ostringstream
+ *
  * Revision 1.10  2004/11/01 16:43:04  strk
  * Added Profiler code.
  * Temporarly patched a bug in DoubleBits (must check drawbacks).
