@@ -1,5 +1,5 @@
 /**********************************************************************
- * $Id: planarDirectedEdge.cpp,v 1.7 2004/12/14 10:35:44 strk Exp $
+ * $Id: planarDirectedEdge.cpp,v 1.7.2.2 2005/05/23 18:41:51 strk Exp $
  *
  * GEOS - Geometry Engine Open Source
  * http://geos.refractions.net
@@ -15,9 +15,9 @@
 
 #include <geos/planargraph.h>
 #include <geos/geomgraph.h>
-#include <math.h>
+#include <cmath>
 #include <typeinfo>
-#include <stdio.h>
+#include <sstream>
 
 namespace geos {
 //namespace planargraph {
@@ -214,16 +214,10 @@ planarDirectedEdge::compareDirection(const planarDirectedEdge *e) const
 string
 planarDirectedEdge::print() const
 {
-	string out=typeid(*this).name();
-	out+=" : ";
-	out+=p0.toString();
-	out+=" - ";
-	out+=p1.toString();
-	char buffer[255];
-	sprintf(buffer," %i:%g) ",quadrant,angle);
-	out.append(buffer);
-	out.append("");
-	return out;
+	ostringstream s;
+	s<<typeid(*this).name()<<": "<<p0.toString()<<" - "<<p1.toString();
+	s<<" "<<quadrant<<":"<<angle;
+	return s.str();
 }
 
 
@@ -233,6 +227,12 @@ planarDirectedEdge::print() const
 
 /**********************************************************************
  * $Log: planarDirectedEdge.cpp,v $
+ * Revision 1.7.2.2  2005/05/23 18:41:51  strk
+ * Replaced sprintf uses with ostringstream
+ *
+ * Revision 1.7.2.1  2005/05/23 17:10:08  strk
+ * Stricter C++ syntax (math.h=>cmath, ieeefp.h in "C" block)
+ *
  * Revision 1.7  2004/12/14 10:35:44  strk
  * Comments cleanup. PolygonizeGraph keeps track of generated CoordinateSequence
  * for delayed destruction.
