@@ -1,5 +1,5 @@
 /**********************************************************************
- * $Id: planarDirectedEdgeStar.cpp,v 1.4 2004/12/14 10:35:44 strk Exp $
+ * $Id: planarDirectedEdgeStar.cpp,v 1.4.2.1 2005/08/22 13:30:32 strk Exp $
  *
  * GEOS - Geometry Engine Open Source
  * http://geos.refractions.net
@@ -103,7 +103,7 @@ planarDirectedEdgeStar::getEdges()
 bool
 pdeLessThan(planarDirectedEdge *first, planarDirectedEdge * second)
 {
-	if (first->compareTo(second)<=0)
+	if (first->compareTo(second)<0)
 		return true;
 	else
 		return false;
@@ -179,6 +179,10 @@ planarDirectedEdgeStar::getNextEdge(planarDirectedEdge *dirEdge)
 
 /**********************************************************************
  * $Log: planarDirectedEdgeStar.cpp,v $
+ * Revision 1.4.2.1  2005/08/22 13:30:32  strk
+ * Fixed comparator functions used with STL sort() algorithm to
+ * implement StrictWeakOrdering semantic.
+ *
  * Revision 1.4  2004/12/14 10:35:44  strk
  * Comments cleanup. PolygonizeGraph keeps track of generated CoordinateSequence
  * for delayed destruction.
